package VMOMI::ClusterDasConfigInfoServiceState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
